==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Panel/Panel.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction, getId, elementContains, getRTL } from '@uifabric-vue/utilities';
import { IconFontSizes } from '@uifabric/styling';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import '../Layer/Layer.base.js';
import { Layer } from '../Layer/Layer.js';
import '../Layer/LayerHost.js';
import { Overlay } from '../Overlay/Overlay.js';
import '../Button/BaseButton.js';
import '../Button/ActionButton/ActionButton.js';
import '../Button/DefaultButton/DefaultButton.js';
import '../Button/PrimaryButton/PrimaryButton.js';
import '../Button/CommandBarButton/CommandBarButton.js';
import '../Button/CompoundButton/CompoundButton.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import '../Button/MessageBarButton/MessageBarButton.js';
import { PanelType } from './Panel.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();
var PanelVisibilityState;

(function (PanelVisibilityState) {
  PanelVisibilityState[PanelVisibilityState["closed"] = 0] = "closed";
  PanelVisibilityState[PanelVisibilityState["animatingOpen"] = 1] = "animatingOpen";
  PanelVisibilityState[PanelVisibilityState["open"] = 2] = "open";
  PanelVisibilityState[PanelVisibilityState["animatingClosed"] = 3] = "animatingClosed";
})(PanelVisibilityState || (PanelVisibilityState = {}));

var PanelBase = function (_BaseComponent) {
  _inherits(PanelBase, _BaseComponent);

  var _super = _createSuper(PanelBase);

  function PanelBase() {
    var _this;

    _classCallCheck(this, PanelBase);

    _this = _super.apply(this, arguments);
    _this.IconFontSizes = IconFontSizes;
    _this.isFooterSticky = false;
    _this.id = getId('Panel');
    _this.visibility = PanelVisibilityState.closed;
    _this.animationCallback = null;
    return _this;
  }

  _createClass(PanelBase, [{
    key: "created",
    value: function created() {
      window.addEventListener('resize', this.updateFooterPosition);

      if (this.shouldListenForOuterClick) {
        window.addEventListener('mousedown', this.dismissOnOuterClick, true);
      }
    }
  }, {
    key: "onIsOpenUpdated",
    value: function onIsOpenUpdated(newVal, prevVal) {
      console.log('onIsOpenUpdated');

      if (newVal) {
        this.visibility = PanelVisibilityState.animatingOpen;
      }
    }
  }, {
    key: "onVisibilityUpdated",
    value: function onVisibilityUpdated(newVal, prevVal) {
      console.log(newVal, prevVal);

      if (newVal !== prevVal) {
        this.clearExistingAnimationTimer();

        if (newVal === PanelVisibilityState.animatingOpen) {
          this.animateTo(PanelVisibilityState.open);
        } else if (newVal === PanelVisibilityState.animatingClosed) {
          this.animateTo(PanelVisibilityState.closed);
        }
      }
    }
  }, {
    key: "close",
    value: function close() {
      console.log('close');
      console.log(this.isOpen, this.isActive, this.visibility);
      if (this.isOpen !== undefined) return;
      if (!this.isActive) return;
      console.log(this.visibility);
      this.visibility = PanelVisibilityState.animatingClosed;
    }
  }, {
    key: "dismiss",
    value: function dismiss(ev) {
      console.log('dismiss');

      if (this.onDismiss) {
        this.onDismiss(ev);
      }

      if (!ev || ev && !ev.defaultPrevented) {
        this.close();
      }
    }
  }, {
    key: "dismissOnOuterClick",
    value: function dismissOnOuterClick(ev) {
      var panel = this.$refs.panel;

      if (this.isActive && panel && !ev.defaultPrevented()) {
        if (!elementContains(panel, ev.target)) {
          if (this.onOuterClick) {
            this.onOuterClick();
            ev.preventDefault();
          } else {
            this.dismiss();
          }
        }
      }
    }
  }, {
    key: "updateFooterPosition",
    value: function updateFooterPosition() {
      var scrollableContent = this.$refs.scrollableContent;

      if (scrollableContent) {
        var height = scrollableContent.clientHeight;
        var innerHeight = scrollableContent.scrollHeight;
        this.isFooterSticky = height < innerHeight;
      }
    }
  }, {
    key: "animateTo",
    value: function animateTo(newVisibilityState) {
      var _this2 = this;

      console.log('animateTo', newVisibilityState);
      this.animationCallback = this._async.setTimeout(function () {
        _this2.visibility = newVisibilityState;

        _this2._onTransitionComplete();
      }, 200);
    }
  }, {
    key: "clearExistingAnimationTimer",
    value: function clearExistingAnimationTimer() {
      if (this.animationCallback !== null) {
        this._async.clearTimeout(this.animationCallback);
      }
    }
  }, {
    key: "_onTransitionComplete",
    value: function _onTransitionComplete() {
      this.updateFooterPosition();

      if (this.visibility === PanelVisibilityState.open && this.onOpened) {
        this.onOpened();
      }

      if (this.visibility === PanelVisibilityState.closed && this.onDismissed) {
        this.onDismissed();
      }
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          isOpen = this.isOpen,
          isAnimating = this.isAnimating,
          isHiddenOnDismiss = this.isHiddenOnDismiss,
          isBlocking = this.isBlocking,
          theme = this.theme,
          headerText = this.headerText;
      if (!isOpen && !isAnimating && !isHiddenOnDismiss) return;
      return h(Layer, [h("div", {
        "ref": "panel",
        "class": classNames.root
      }, [isBlocking && isOpen && h(Overlay, {
        "class": classNames.overlay
      }), h("div", {
        "class": classNames.main
      }, [h("div", {
        "class": classNames.commands
      }, [h("div", {
        "class": classNames.navigation
      }, [h(IconButton, {
        "class": classNames.closeButton,
        "attrs": {
          "styles": {
            root: {
              height: 'auto',
              width: '44px',
              color: theme.palette.neutralSecondary,
              fontSize: IconFontSizes.large
            },
            rootHovered: {
              color: theme.palette.neutralPrimary
            }
          },
          "icon-props": {
            iconName: 'Cancel'
          }
        },
        "nativeOn": {
          "click": this.dismiss
        }
      })])]), h("div", {
        "class": classNames.contentInner
      }, [h("div", {
        "class": classNames.header
      }, [h("p", {
        "class": classNames.headerText
      }, [this.$slots.header || headerText])]), h("div", {
        "ref": "scrollableContent",
        "class": classNames.scrollableContent
      }, [h("div", {
        "class": classNames.content
      }, [this.$slots["default"]])])])])])]);
    }
  }, {
    key: "shouldListenForOuterClick",
    get: function get() {
      return !!this.isBlocking && !!this.isOpen;
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          _this$className = this.className,
          className = _this$className === void 0 ? '' : _this$className,
          focusTrapZoneProps = this.focusTrapZoneProps,
          hasCloseButton = this.hasCloseButton,
          _this$headerClassName = this.headerClassName,
          headerClassName = _this$headerClassName === void 0 ? '' : _this$headerClassName,
          isFooterSticky = this.isFooterSticky,
          isFooterAtBottom = this.isFooterAtBottom,
          isHiddenOnDismiss = this.isHiddenOnDismiss,
          type = this.type;
      var visibility = this.visibility;
      var isOpen = this.isActive;
      var isAnimating = visibility === PanelVisibilityState.animatingClosed || visibility === PanelVisibilityState.animatingOpen;
      var isLeft = !!(type === PanelType.smallFixedNear || type === PanelType.customNear);
      var isRTL = getRTL(theme);
      var isOnRightSide = isRTL ? isLeft : !isLeft;
      return getClassNames(styles, {
        theme: theme,
        className: className,
        focusTrapZoneClassName: focusTrapZoneProps ? focusTrapZoneProps.className : undefined,
        hasCloseButton: hasCloseButton,
        headerClassName: headerClassName,
        isAnimating: isAnimating,
        isFooterSticky: isFooterSticky,
        isFooterAtBottom: isFooterAtBottom,
        isOnRightSide: isOnRightSide,
        isOpen: isOpen,
        isHiddenOnDismiss: isHiddenOnDismiss,
        type: type,
        hasCustomNavigation: false
      });
    }
  }, {
    key: "isAnimating",
    get: function get() {
      var visibility = this.visibility;
      return visibility === PanelVisibilityState.animatingClosed || visibility === PanelVisibilityState.animatingOpen;
    }
  }, {
    key: "isActive",
    get: function get() {
      return this.visibility === PanelVisibilityState.open || this.visibility === PanelVisibilityState.animatingOpen;
    }
  }]);

  return PanelBase;
}(BaseComponent);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], PanelBase.prototype, "headerText", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PanelBase.prototype, "focusTrapZoneProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PanelBase.prototype, "headerClassName", void 0);

__decorate([Prop({
  type: Number,
  "default": PanelType.smallFixedFar
}), __metadata("design:type", Number)], PanelBase.prototype, "type", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], PanelBase.prototype, "onDismiss", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], PanelBase.prototype, "onDismissed", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], PanelBase.prototype, "onOpened", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], PanelBase.prototype, "onOuterClick", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], PanelBase.prototype, "hasCloseButton", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isFooterAtBottom", void 0);

__decorate([Prop({
  type: Boolean,
  "default": null
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isOpen", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isHiddenOnDismiss", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isBlocking", void 0);

__decorate([Watch('isOpen'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], PanelBase.prototype, "onIsOpenUpdated", null);

__decorate([Watch('visibility'), __metadata("design:type", Function), __metadata("design:paramtypes", [Number, Number]), __metadata("design:returntype", void 0)], PanelBase.prototype, "onVisibilityUpdated", null);

PanelBase = __decorate([Component], PanelBase);

export { PanelBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Panel/Panel.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction, getId, elementContains, getRTL } from '@uifabric-vue/utilities';
import { IconFontSizes } from '@uifabric/styling';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.number.constructor';
import '../Layer/Layer.base.js';
import { Layer } from '../Layer/Layer.js';
import '../Layer/LayerHost.js';
import { Overlay } from '../Overlay/Overlay.js';
import '../Button/BaseButton.js';
import '../Button/ActionButton/ActionButton.js';
import '../Button/DefaultButton/DefaultButton.js';
import '../Button/PrimaryButton/PrimaryButton.js';
import '../Button/CommandBarButton/CommandBarButton.js';
import '../Button/CompoundButton/CompoundButton.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import '../Button/MessageBarButton/MessageBarButton.js';
import { PanelType } from './Panel.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();
var PanelVisibilityState;

(function (PanelVisibilityState) {
  PanelVisibilityState[PanelVisibilityState["closed"] = 0] = "closed";
  PanelVisibilityState[PanelVisibilityState["animatingOpen"] = 1] = "animatingOpen";
  PanelVisibilityState[PanelVisibilityState["open"] = 2] = "open";
  PanelVisibilityState[PanelVisibilityState["animatingClosed"] = 3] = "animatingClosed";
})(PanelVisibilityState || (PanelVisibilityState = {}));

var PanelBase = function (_BaseComponent) {
  _inherits(PanelBase, _BaseComponent);

  var _super = _createSuper(PanelBase);

  function PanelBase() {
    var _this;

    _classCallCheck(this, PanelBase);

    _this = _super.apply(this, arguments);
    _this.IconFontSizes = IconFontSizes;
    _this.isFooterSticky = false;
    _this.id = getId('Panel');
    _this.visibility = PanelVisibilityState.closed;
    _this.animationCallback = null;
    return _this;
  }

  _createClass(PanelBase, [{
    key: "created",
    value: function created() {
      window.addEventListener('resize', this.updateFooterPosition);

      if (this.shouldListenForOuterClick) {
        window.addEventListener('mousedown', this.dismissOnOuterClick, true);
      }
    }
  }, {
    key: "onIsOpenUpdated",
    value: function onIsOpenUpdated(newVal, prevVal) {
      console.log('onIsOpenUpdated');

      if (newVal) {
        this.visibility = PanelVisibilityState.animatingOpen;
      }
    }
  }, {
    key: "onVisibilityUpdated",
    value: function onVisibilityUpdated(newVal, prevVal) {
      console.log(newVal, prevVal);

      if (newVal !== prevVal) {
        this.clearExistingAnimationTimer();

        if (newVal === PanelVisibilityState.animatingOpen) {
          this.animateTo(PanelVisibilityState.open);
        } else if (newVal === PanelVisibilityState.animatingClosed) {
          this.animateTo(PanelVisibilityState.closed);
        }
      }
    }
  }, {
    key: "close",
    value: function close() {
      console.log('close');
      console.log(this.isOpen, this.isActive, this.visibility);
      if (this.isOpen !== undefined) return;
      if (!this.isActive) return;
      console.log(this.visibility);
      this.visibility = PanelVisibilityState.animatingClosed;
    }
  }, {
    key: "dismiss",
    value: function dismiss(ev) {
      console.log('dismiss');

      if (this.onDismiss) {
        this.onDismiss(ev);
      }

      if (!ev || ev && !ev.defaultPrevented) {
        this.close();
      }
    }
  }, {
    key: "dismissOnOuterClick",
    value: function dismissOnOuterClick(ev) {
      var panel = this.$refs.panel;

      if (this.isActive && panel && !ev.defaultPrevented()) {
        if (!elementContains(panel, ev.target)) {
          if (this.onOuterClick) {
            this.onOuterClick();
            ev.preventDefault();
          } else {
            this.dismiss();
          }
        }
      }
    }
  }, {
    key: "updateFooterPosition",
    value: function updateFooterPosition() {
      var scrollableContent = this.$refs.scrollableContent;

      if (scrollableContent) {
        var height = scrollableContent.clientHeight;
        var innerHeight = scrollableContent.scrollHeight;
        this.isFooterSticky = height < innerHeight;
      }
    }
  }, {
    key: "animateTo",
    value: function animateTo(newVisibilityState) {
      var _this2 = this;

      console.log('animateTo', newVisibilityState);
      this.animationCallback = this._async.setTimeout(function () {
        _this2.visibility = newVisibilityState;

        _this2._onTransitionComplete();
      }, 200);
    }
  }, {
    key: "clearExistingAnimationTimer",
    value: function clearExistingAnimationTimer() {
      if (this.animationCallback !== null) {
        this._async.clearTimeout(this.animationCallback);
      }
    }
  }, {
    key: "_onTransitionComplete",
    value: function _onTransitionComplete() {
      this.updateFooterPosition();

      if (this.visibility === PanelVisibilityState.open && this.onOpened) {
        this.onOpened();
      }

      if (this.visibility === PanelVisibilityState.closed && this.onDismissed) {
        this.onDismissed();
      }
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          isOpen = this.isOpen,
          isAnimating = this.isAnimating,
          isHiddenOnDismiss = this.isHiddenOnDismiss,
          isBlocking = this.isBlocking,
          theme = this.theme,
          headerText = this.headerText;
      if (!isOpen && !isAnimating && !isHiddenOnDismiss) return;
      return h(Layer, [h("div", {
        "ref": "panel",
        "class": classNames.root
      }, [isBlocking && isOpen && h(Overlay, {
        "class": classNames.overlay
      }), h("div", {
        "class": classNames.main
      }, [h("div", {
        "class": classNames.commands
      }, [h("div", {
        "class": classNames.navigation
      }, [h(IconButton, {
        "class": classNames.closeButton,
        "attrs": {
          "styles": {
            root: {
              height: 'auto',
              width: '44px',
              color: theme.palette.neutralSecondary,
              fontSize: IconFontSizes.large
            },
            rootHovered: {
              color: theme.palette.neutralPrimary
            }
          },
          "icon-props": {
            iconName: 'Cancel'
          }
        },
        "nativeOn": {
          "click": this.dismiss
        }
      })])]), h("div", {
        "class": classNames.contentInner
      }, [h("div", {
        "class": classNames.header
      }, [h("p", {
        "class": classNames.headerText
      }, [this.$slots.header || headerText])]), h("div", {
        "ref": "scrollableContent",
        "class": classNames.scrollableContent
      }, [h("div", {
        "class": classNames.content
      }, [this.$slots.default])])])])])]);
    }
  }, {
    key: "shouldListenForOuterClick",
    get: function get() {
      return !!this.isBlocking && !!this.isOpen;
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          _this$className = this.className,
          className = _this$className === void 0 ? '' : _this$className,
          focusTrapZoneProps = this.focusTrapZoneProps,
          hasCloseButton = this.hasCloseButton,
          _this$headerClassName = this.headerClassName,
          headerClassName = _this$headerClassName === void 0 ? '' : _this$headerClassName,
          isFooterSticky = this.isFooterSticky,
          isFooterAtBottom = this.isFooterAtBottom,
          isHiddenOnDismiss = this.isHiddenOnDismiss,
          type = this.type;
      var visibility = this.visibility;
      var isOpen = this.isActive;
      var isAnimating = visibility === PanelVisibilityState.animatingClosed || visibility === PanelVisibilityState.animatingOpen;
      var isLeft = !!(type === PanelType.smallFixedNear || type === PanelType.customNear);
      var isRTL = getRTL(theme);
      var isOnRightSide = isRTL ? isLeft : !isLeft;
      return getClassNames(styles, {
        theme: theme,
        className: className,
        focusTrapZoneClassName: focusTrapZoneProps ? focusTrapZoneProps.className : undefined,
        hasCloseButton: hasCloseButton,
        headerClassName: headerClassName,
        isAnimating: isAnimating,
        isFooterSticky: isFooterSticky,
        isFooterAtBottom: isFooterAtBottom,
        isOnRightSide: isOnRightSide,
        isOpen: isOpen,
        isHiddenOnDismiss: isHiddenOnDismiss,
        type: type,
        hasCustomNavigation: false
      });
    }
  }, {
    key: "isAnimating",
    get: function get() {
      var visibility = this.visibility;
      return visibility === PanelVisibilityState.animatingClosed || visibility === PanelVisibilityState.animatingOpen;
    }
  }, {
    key: "isActive",
    get: function get() {
      return this.visibility === PanelVisibilityState.open || this.visibility === PanelVisibilityState.animatingOpen;
    }
  }]);

  return PanelBase;
}(BaseComponent);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PanelBase.prototype, "headerText", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PanelBase.prototype, "focusTrapZoneProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PanelBase.prototype, "headerClassName", void 0);

__decorate([Prop({
  type: Number,
  default: PanelType.smallFixedFar
}), __metadata("design:type", Number)], PanelBase.prototype, "type", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], PanelBase.prototype, "onDismiss", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], PanelBase.prototype, "onDismissed", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], PanelBase.prototype, "onOpened", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], PanelBase.prototype, "onOuterClick", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], PanelBase.prototype, "hasCloseButton", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isFooterAtBottom", void 0);

__decorate([Prop({
  type: Boolean,
  default: null
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isOpen", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isHiddenOnDismiss", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], PanelBase.prototype, "isBlocking", void 0);

__decorate([Watch('isOpen'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], PanelBase.prototype, "onIsOpenUpdated", null);

__decorate([Watch('visibility'), __metadata("design:type", Function), __metadata("design:paramtypes", [Number, Number]), __metadata("design:returntype", void 0)], PanelBase.prototype, "onVisibilityUpdated", null);

PanelBase = __decorate([Component], PanelBase);

export { PanelBase };
